==> jc-1.4.0.tar.gz: gnu/xml/dom/DomDocumentBuilderFactory.h <==
// public class gnu.xml.dom.DomDocumentBuilderFactory

// class file dependencies
// @dep_class ed841c2e4adfbfb4 gnu_xml_dom_DomDocumentBuilderFactory
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2ac95ce8b4614a01 javax_xml_parsers_DocumentBuilderFactory

// header file dependencies
// @dep_header javax_xml_parsers_DocumentBuilderFactory

#include "javax/xml/parsers/DocumentBuilderFactory.h"

#ifndef _JC_gnu_xml_dom_DomDocumentBuilderFactory_H_
#define _JC_gnu_xml_dom_DomDocumentBuilderFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_parsers_DocumentBuilder$object;
struct _jc_org_w3c_dom_DOMConfiguration$object;
struct _jc_org_w3c_dom_DOMImplementation$object;
struct _jc_org_w3c_dom_ls_DOMImplementationLS$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$sub_refs	_jc_gnu_xml_dom_DomDocumentBuilderFactory$sub_refs;
typedef struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$sub_nonrefs	_jc_gnu_xml_dom_DomDocumentBuilderFactory$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$refs	_jc_gnu_xml_dom_DomDocumentBuilderFactory$refs;
typedef struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$nonrefs	_jc_gnu_xml_dom_DomDocumentBuilderFactory$nonrefs;
typedef struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$object	_jc_gnu_xml_dom_DomDocumentBuilderFactory$object;

typedef const struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$vmethods	_jc_gnu_xml_dom_DomDocumentBuilderFactory$vmethods;
typedef const struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$vtable	_jc_gnu_xml_dom_DomDocumentBuilderFactory$vtable;
typedef const struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$vtype	_jc_gnu_xml_dom_DomDocumentBuilderFactory$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomDocumentBuilderFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_dom_DomDocumentBuilderFactory$method$getAttribute$bd4ba72dbd34d711(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$object *, struct _jc_java_lang_String$object *);
extern struct _jc_javax_xml_parsers_DocumentBuilder$object *_jc_gnu_xml_dom_DomDocumentBuilderFactory$method$newDocumentBuilder$e5d58fd72aab1990(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$object *);
extern void _jc_gnu_xml_dom_DomDocumentBuilderFactory$method$setAttribute$f7af18cb25a05ce1(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *);
extern void _jc_gnu_xml_dom_DomDocumentBuilderFactory$method$setParameter$9c9a03cbf0fb6c67(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomDocumentBuilderFactory$method_info$getAttribute$bd4ba72dbd34d711;
extern _jc_method _jc_gnu_xml_dom_DomDocumentBuilderFactory$method_info$newDocumentBuilder$e5d58fd72aab1990;
extern _jc_method _jc_gnu_xml_dom_DomDocumentBuilderFactory$method_info$setAttribute$f7af18cb25a05ce1;
extern _jc_method _jc_gnu_xml_dom_DomDocumentBuilderFactory$method_info$setParameter$9c9a03cbf0fb6c67;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$vmethods {
	struct _jc_java_lang_Object$object	*(*getAttribute$bd4ba72dbd34d711)(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$object *, struct _jc_java_lang_String$object *);
	struct _jc_javax_xml_parsers_DocumentBuilder$object	*(*newDocumentBuilder$e5d58fd72aab1990)(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$object *);
	void	(*setAttribute$f7af18cb25a05ce1)(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *);
	void	(*setParameter$9c9a03cbf0fb6c67)(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_parsers_DocumentBuilderFactory$vmethods	javax_xml_parsers_DocumentBuilderFactory;
	_jc_gnu_xml_dom_DomDocumentBuilderFactory$vmethods	gnu_xml_dom_DomDocumentBuilderFactory;
};

// Vtype
struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomDocumentBuilderFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$sub_refs {
	struct _jc_object	*impl;
	struct _jc_object	*ls;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$refs {
    _jc_gnu_xml_dom_DomDocumentBuilderFactory$sub_refs	gnu_xml_dom_DomDocumentBuilderFactory;
    _jc_javax_xml_parsers_DocumentBuilderFactory$sub_refs	javax_xml_parsers_DocumentBuilderFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_parsers_DocumentBuilderFactory$sub_nonrefs	javax_xml_parsers_DocumentBuilderFactory;
    _jc_gnu_xml_dom_DomDocumentBuilderFactory$sub_nonrefs	gnu_xml_dom_DomDocumentBuilderFactory;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$object {
	_jc_gnu_xml_dom_DomDocumentBuilderFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomDocumentBuilderFactory$vtype	*vtype;
	_jc_gnu_xml_dom_DomDocumentBuilderFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomDocumentBuilderFactory$vtype _jc_gnu_xml_dom_DomDocumentBuilderFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomDocumentBuilderFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomDocumentBuilderFactory$class_object;

#endif	/* _JC_gnu_xml_dom_DomDocumentBuilderFactory_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/dom/DomDocumentBuilderFactory.h <==
// public class gnu.xml.dom.DomDocumentBuilderFactory

// class file dependencies
// @dep_class ed841c2e4adfbfb4 gnu_xml_dom_DomDocumentBuilderFactory
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2ac95ce8b4614a01 javax_xml_parsers_DocumentBuilderFactory

// header file dependencies
// @dep_header javax_xml_parsers_DocumentBuilderFactory

#include "javax/xml/parsers/DocumentBuilderFactory.h"

#ifndef _JC_gnu_xml_dom_DomDocumentBuilderFactory_H_
#define _JC_gnu_xml_dom_DomDocumentBuilderFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_parsers_DocumentBuilder$object;
struct _jc_org_w3c_dom_DOMConfiguration$object;
struct _jc_org_w3c_dom_DOMImplementation$object;
struct _jc_org_w3c_dom_ls_DOMImplementationLS$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$sub_refs	_jc_gnu_xml_dom_DomDocumentBuilderFactory$sub_refs;
typedef struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$sub_nonrefs	_jc_gnu_xml_dom_DomDocumentBuilderFactory$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$refs	_jc_gnu_xml_dom_DomDocumentBuilderFactory$refs;
typedef struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$nonrefs	_jc_gnu_xml_dom_DomDocumentBuilderFactory$nonrefs;
typedef struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$object	_jc_gnu_xml_dom_DomDocumentBuilderFactory$object;

typedef const struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$vmethods	_jc_gnu_xml_dom_DomDocumentBuilderFactory$vmethods;
typedef const struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$vtable	_jc_gnu_xml_dom_DomDocumentBuilderFactory$vtable;
typedef const struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$vtype	_jc_gnu_xml_dom_DomDocumentBuilderFactory$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomDocumentBuilderFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_dom_DomDocumentBuilderFactory$method$getAttribute$bd4ba72dbd34d711(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_xml_parsers_DocumentBuilder$object *_jc_gnu_xml_dom_DomDocumentBuilderFactory$method$newDocumentBuilder$e5d58fd72aab1990(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_dom_DomDocumentBuilderFactory$method$setAttribute$f7af18cb25a05ce1(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_dom_DomDocumentBuilderFactory$method$setParameter$9c9a03cbf0fb6c67(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomDocumentBuilderFactory$method_info$getAttribute$bd4ba72dbd34d711;
extern _jc_method _jc_gnu_xml_dom_DomDocumentBuilderFactory$method_info$newDocumentBuilder$e5d58fd72aab1990;
extern _jc_method _jc_gnu_xml_dom_DomDocumentBuilderFactory$method_info$setAttribute$f7af18cb25a05ce1;
extern _jc_method _jc_gnu_xml_dom_DomDocumentBuilderFactory$method_info$setParameter$9c9a03cbf0fb6c67;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$vmethods {
	struct _jc_java_lang_Object$object	*(*getAttribute$bd4ba72dbd34d711)(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_javax_xml_parsers_DocumentBuilder$object	*(*newDocumentBuilder$e5d58fd72aab1990)(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$object *) _JC_JCNI_ATTR;
	void	(*setAttribute$f7af18cb25a05ce1)(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*setParameter$9c9a03cbf0fb6c67)(_jc_env *, struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_parsers_DocumentBuilderFactory$vmethods	javax_xml_parsers_DocumentBuilderFactory;
	_jc_gnu_xml_dom_DomDocumentBuilderFactory$vmethods	gnu_xml_dom_DomDocumentBuilderFactory;
};

// Vtype
struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomDocumentBuilderFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$sub_refs {
	struct _jc_object	*impl;
	struct _jc_object	*ls;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$refs {
    _jc_gnu_xml_dom_DomDocumentBuilderFactory$sub_refs	gnu_xml_dom_DomDocumentBuilderFactory;
    _jc_javax_xml_parsers_DocumentBuilderFactory$sub_refs	javax_xml_parsers_DocumentBuilderFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_parsers_DocumentBuilderFactory$sub_nonrefs	javax_xml_parsers_DocumentBuilderFactory;
    _jc_gnu_xml_dom_DomDocumentBuilderFactory$sub_nonrefs	gnu_xml_dom_DomDocumentBuilderFactory;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomDocumentBuilderFactory$object {
	_jc_gnu_xml_dom_DomDocumentBuilderFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomDocumentBuilderFactory$vtype	*vtype;
	_jc_gnu_xml_dom_DomDocumentBuilderFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomDocumentBuilderFactory$vtype _jc_gnu_xml_dom_DomDocumentBuilderFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomDocumentBuilderFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomDocumentBuilderFactory$class_object;

#endif	/* _JC_gnu_xml_dom_DomDocumentBuilderFactory_H_ */
